pub struct EnvVarsConfig {
pub key: String,
pub value: String,
}Fields
key: Stringvalue: StringTrait Implementations
Sourceimpl Clone for EnvVarsConfig
impl Clone for EnvVarsConfig
Sourcefn clone(&self) -> EnvVarsConfig
fn clone(&self) -> EnvVarsConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EnvVarsConfig
impl Debug for EnvVarsConfig
Sourceimpl<'de> Deserialize<'de> for EnvVarsConfig
impl<'de> Deserialize<'de> for EnvVarsConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EnvVarsConfig
impl JsonSchema for EnvVarsConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EnvVarsConfig
impl RefUnwindSafe for EnvVarsConfig
impl Send for EnvVarsConfig
impl Sync for EnvVarsConfig
impl Unpin for EnvVarsConfig
impl UnsafeUnpin for EnvVarsConfig
impl UnwindSafe for EnvVarsConfig