pub struct OnePasswordSSHAgentConfig {
pub keys: Vec<OnePasswordSSHKey>,
}Fields
keys: Vec<OnePasswordSSHKey>Trait Implementations
Sourceimpl Clone for OnePasswordSSHAgentConfig
impl Clone for OnePasswordSSHAgentConfig
Sourcefn clone(&self) -> OnePasswordSSHAgentConfig
fn clone(&self) -> OnePasswordSSHAgentConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OnePasswordSSHAgentConfig
impl Debug for OnePasswordSSHAgentConfig
Sourceimpl Default for OnePasswordSSHAgentConfig
impl Default for OnePasswordSSHAgentConfig
Sourcefn default() -> OnePasswordSSHAgentConfig
fn default() -> OnePasswordSSHAgentConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OnePasswordSSHAgentConfig
impl<'de> Deserialize<'de> for OnePasswordSSHAgentConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OnePasswordSSHAgentConfig
impl JsonSchema for OnePasswordSSHAgentConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OnePasswordSSHAgentConfig
impl RefUnwindSafe for OnePasswordSSHAgentConfig
impl Send for OnePasswordSSHAgentConfig
impl Sync for OnePasswordSSHAgentConfig
impl Unpin for OnePasswordSSHAgentConfig
impl UnsafeUnpin for OnePasswordSSHAgentConfig
impl UnwindSafe for OnePasswordSSHAgentConfig